using UnityEngine;

namespace CSSticks
{
        public class EmergencySirenBehaviour : MonoBehaviour
        {
            public DamagableMachineryBehaviour damagableMachineryBehaviour;
            public AudioSource audioSource;
            public bool activated = false;

            private void Use()
            {
                if (this.damagableMachineryBehaviour.Destroyed)
                    return;

                this.activated = !this.activated;

                if (this.activated)
                {
                    this.audioSource.Play();
                    return;
                }

                this.audioSource.Stop();
            }

            void FixedUpdate() {
                if (this.damagableMachineryBehaviour.Destroyed && this.audioSource.isPlaying)
                {
                    this.audioSource.Stop();
                    this.activated = false;
                }
            }
        }

        public class UniversalSirenBehaviour : EmergencySirenBehaviour
        {
            public int soundIndex = 0;
            public AudioClip[] sounds;
            public string[] names;

            private void Use()
            {
                if (this.damagableMachineryBehaviour.Destroyed)
                    return;

                this.activated = !this.activated;

                if (this.activated)
                {
                    this.audioSource.Play();
                    return;
                }

                this.audioSource.Stop();
            }

            public void ChangeSound(bool next) {
                if (this.activated)
                    this.audioSource.Stop();

                soundIndex += next ? 1 : -1;

                if (soundIndex >= sounds.Length)
                    soundIndex = 0;
                else if (soundIndex < 0)
                    soundIndex = sounds.Length - 1;

                this.audioSource.clip = this.sounds[soundIndex];

                if (this.activated)
                    this.audioSource.Play();
            }
        }
    }
