using UnityEngine;
using System;
using System.Collections.Generic;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.IO;
using System.Security.Permissions;


namespace CSSticks
{
    public class StickyBehaviour : MonoBehaviour
    {
        private bool activated = false;
        private void Awake()
        {
            this.unstickyPropertySet = new List<PhysicalProperties>(this.StickyPropertiesToIgnore);
            this.StickyPropertiesToIgnore = null;
            this.objectLayer = LayerMask.NameToLayer("Objects");
            this.nocollisionLayer = LayerMask.NameToLayer("Debris");
        }

        private void FixedUpdate()
        {
            bool flag = this.isStuck && this.joint && !this.joint.connectedBody;
            bool flag2 = !this.isStuck && this.joint;
            if ((this.isStuck && !this.joint) || flag2 || flag)
            {
                this.DestroyJoint();
            }
        }



        private void Use()
        {
            if (activated == false)
            {
                activated = true;
                if (gameObject.GetComponent<StickyBehaviour>() != null)
                {
                    gameObject.GetComponent<StickyBehaviour>().armed = true;
                }

            }
        }


        private void OnCollisionEnter2D(Collision2D collision)
        {
            if (this.isStuck || !this.armed)
            {
                return;
            }
            PhysicalBehaviour phys;
            if (!this.GetPhysicalBehaviour(collision, out phys))
            {
                return;
            }
            if (!this.IsStickyWith(phys))
            {
                return;
            }
            this.isStuck = true;
            this.CreateJoint(phys);
        }
        private void OnJointBreak2D(Joint2D broken)
        {
            if (broken != this.joint)
            {
                return;
            }
            this.DestroyJoint();
        }
        private bool GetPhysicalBehaviour(Collision2D collision, out PhysicalBehaviour phys)
        {
            return Global.main.PhysicalObjectsInWorldByTransform.TryGetValue(collision.transform, out phys);
        }
        private bool IsStickyWith(PhysicalBehaviour phys)
        {
            return !this.unstickyPropertySet.Contains(phys.Properties);
        }
        private void CreateJoint(PhysicalBehaviour phys)
        {
            if (this.joint)
            {
                UnityEngine.Object.Destroy(this.joint);
            }
            this.joint = base.gameObject.AddComponent<FixedJoint2D>();
            this.joint.connectedBody = phys.rigidbody;
            base.gameObject.layer = this.nocollisionLayer;
        }
        private void DestroyJoint()
        {
            base.gameObject.layer = this.objectLayer;
            this.isStuck = false;
            if (this.joint)
            {
                UnityEngine.Object.Destroy(this.joint);
            }
        }
        [SkipSerialisation]
        public PhysicalProperties[] StickyPropertiesToIgnore = new PhysicalProperties[0];
        private bool isStuck;
        private List<PhysicalProperties> unstickyPropertySet;
        private FixedJoint2D joint;
        public bool armed = false;
        private int objectLayer;
        private int nocollisionLayer;
    }
}
